pub struct DisplayOptions {
pub projection: Option<IndexMap<String, String>>,
pub projection_table_only: bool,
pub extra: Map<String, Value>,
pub empty_message: Option<String>,
}Expand description
Display options.
Fields
projection: Option<IndexMap<String, String>>An ordered list of keys indicating which parts of the map should be used (i.e., a projection).
projection_table_only: boolWhether projection should be applied only when the format is table.
extra: Map<String, Value>Extra fields.
empty_message: Option<String>Empty message.
Implementations
Sourceimpl DisplayOptions
impl DisplayOptions
Sourcepub fn table_projection(
keys: impl IntoIterator<Item = (impl ToString, impl ToString)>,
) -> Self
pub fn table_projection( keys: impl IntoIterator<Item = (impl ToString, impl ToString)>, ) -> Self
Create a projection for table format only.
Sourcepub fn projection(
keys: impl IntoIterator<Item = (impl ToString, impl ToString)>,
projection_table_only: bool,
) -> Self
pub fn projection( keys: impl IntoIterator<Item = (impl ToString, impl ToString)>, projection_table_only: bool, ) -> Self
Create a projection.
Sourcepub fn set_empty_message(self, message: impl ToString) -> Self
pub fn set_empty_message(self, message: impl ToString) -> Self
Set message to display when the table is empty.